==> qmmp-1.7.9.tar.bz2: qmmp-1.7.9/src/plugins/Effect/soxr/translations/soxr_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>EffectSoXRFactory</name>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="30"/>
        <source>SoX Resampler Plugin</source>
        <translation>SoX重新取样器插件</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="50"/>
        <source>About SoX Resampler Plugin</source>
        <translation>关于SoX重新取样器插件</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="51"/>
        <source>Qmmp SoX Resampler Plugin</source>
        <translation>Qmmp SoX 重新取样器插件</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SoXRSettingsDialog</name>
    <message>
        <location filename="../soxrsettingsdialog.ui" line="14"/>
        <source>Sample Rate Converter Plugin Settings</source>
        <translation>取样率转换插件设置</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.ui" line="20"/>
        <source>Sample Rate (Hz):</source>
        <translation>取样率 (Hz)：</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.ui" line="40"/>
        <source>Quality:</source>
        <translation>质量：</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.cpp" line="34"/>
        <source>Quick</source>
        <translation>快速</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.cpp" line="35"/>
        <source>Low</source>
        <translation>低</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.cpp" line="36"/>
        <source>Medium</source>
        <translation>中等</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.cpp" line="37"/>
        <source>High</source>
        <translation>高</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.cpp" line="38"/>
        <source>Very High</source>
        <translation>非常高</translation>
    </message>
</context>
</TS>

==> qmmp_2.2.3.orig.tar.bz2: qmmp-2.2.3/src/plugins/Effect/soxr/translations/soxr_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>EffectSoXRFactory</name>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="30"/>
        <source>SoX Resampler Plugin</source>
        <translation>SoX重新取样器插件</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="50"/>
        <source>About SoX Resampler Plugin</source>
        <translation>关于SoX重新取样器插件</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="51"/>
        <source>Qmmp SoX Resampler Plugin</source>
        <translation>Qmmp SoX 重新取样器插件</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SoXRSettingsDialog</name>
    <message>
        <location filename="../soxrsettingsdialog.ui" line="14"/>
        <source>Sample Rate Converter Plugin Settings</source>
        <translation>取样率转换插件设置</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.ui" line="20"/>
        <source>Sample Rate (Hz):</source>
        <translation>取样率 (Hz)：</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.ui" line="40"/>
        <source>Quality:</source>
        <translation>质量：</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.cpp" line="34"/>
        <source>Quick</source>
        <translation>快速</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.cpp" line="35"/>
        <source>Low</source>
        <translation>低</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.cpp" line="36"/>
        <source>Medium</source>
        <translation>中等</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.cpp" line="37"/>
        <source>High</source>
        <translation>高</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.cpp" line="38"/>
        <source>Very High</source>
        <translation>非常高</translation>
    </message>
</context>
</TS>
